##  Editable and Non-Editable Fields
Not all fields can be edited in inline editing, and such fields are greyed out in the table during editing.
Editable Fields | Non-Editable Fields
---|---
  * Text
  * Number
  * Single and multi-select field
  * Date
  * Tags
  * Subscriptions
  * Quality seal*
  * Relation**
  * Fields on relations

|
  * Base Fields (e.g., Fact sheet type, ID, etc.)
  * Calculated Fields (e.g., Display Name)
  * Documents




*Quality seal can be edited only when one specific fact sheet type is listed in the table.
**To edit relations, make sure to unhide the relation’s display name by clicking the eye icon.
![Unhiding the Relation’s Display Name to Edit Relations](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274d04b37a441014bfdfc93de0984433_LowRes.png)
Unhiding the Relation’s Display Name to Edit Relations
